@@ -4,10 +4,9 @@
 # @Email: 1727949032@qq.com
 # @Software: PyCharm
 from elasticsearch5 import Elasticsearch
-from py3db.log.Log import Log, singleton
+from py3db.log.Log import Log
 
 
-@singleton
 class ElasticSearch(object):
     def __init__(self, es_address_list=['127.0.0.1:9200']):
         self.es = Elasticsearch(
