@@ -3,19 +3,19 @@ from os.path import join
 from os import getcwd
 
 
-def Singleton(cls):
-    _instnce = {}
+def singleton(cls):
+    _instance = {}
 
     @wraps(cls)
-    def _singlenton(*args, **kwargs):
-        if cls not in _instnce:
-            _instnce[cls] = cls(*args, **kwargs)
-        return _instnce[cls]
+    def _singleton(*args, **kwargs):
+        if cls not in _instance:
+            _instance[cls] = cls(*args, **kwargs)
+        return _instance[cls]
 
-    return _singlenton
+    return _singleton
 
 
-@Singleton
+@singleton
 class Log:
     def __init__(self, file_name):
         self.file_name = file_name
