@@ -1,8 +1,7 @@
-from py3db.log.Log import Log, singleton
+from py3db.log.Log import Log
 from pymysql import connect
 
 
-@singleton
 class MySql:
     def __init__(self, ip, user_name, password, database):
         self.ip = ip
